<script setup>
import { ref } from 'vue';
import { useI18n } from 'vue-i18n';
import { useForm } from '@inertiajs/vue3';

import i18n from '@/Core/i18n';
import Button from '@/Shared/Button.vue';
import CheckBox from '@/Shared/CheckBox.vue';
import JetLabel from '@/Jetstream/Label.vue';
import TextInput from '@/Shared/TextInput.vue';
import AppLayout from '@/Layouts/AppLayout.vue';
import SelectInput from '@/Shared/SelectInput.vue';
import FormSection from '@/Jetstream/FormSection.vue';
import JetInputError from '@/Jetstream/InputError.vue';
import AutoComplete from '@/Shared/AutoComplete.vue';
import SectionTitle from '@/Jetstream/SectionTitle.vue';
import ActionMessage from '@/Jetstream/ActionMessage.vue';
import JetSecondaryButton from '@/Jetstream/SecondaryButton.vue';

const props = defineProps(['current', 'languages']);
const { t } = useI18n({});

const logoInput = ref(null);
const logoPreview = ref(null);
const invoiceLogoInput = ref(null);
const invoiceLogoPreview = ref(null);

const form = useForm({
  name: props.current?.name,
  language: props.current?.language || 'en',
  per_page: props.current?.per_page || 10,
  fraction: props.current.fraction,
  hour12: props.current.hour12 || '1',
  reference: props.current?.reference || 'ulid',
  initial_rows: props.current?.initial_rows,
  invoice_status: props.current?.invoice_status,
  currency_code: props.current?.currency_code || 'USD',
  default_locale: props.current?.default_locale || 'en-US',
  paypal: props.current?.paypal || { enabled: false },
  stripe: props.current?.stripe || { enabled: false },
  product_discount: props.current?.product_discount == 1,
  impersonation: props.current?.impersonation == 1,
  create_user: props.current?.create_user == 1,
  login_logo: props.current?.login_logo || null,
  invoice_logo: props.current?.invoice_logo || null,
  attachment_exts: props.current.attachment_exts || 'jpg,png,pdf,xlsx,docx,zip',
});

const submit = () => {
  if (logoInput.value) {
    form.login_logo = logoInput.value.files[0];
  }
  if (invoiceLogoInput.value) {
    form.invoice_logo = invoiceLogoInput.value.files[0];
  }

  form.post(route('settings.store'), {
    onSuccess: p => {
      i18n.global.locale.value = p.props.settings.language;
      document.querySelector('html').setAttribute('lang', p.props.settings.language);
    },
  });
};

const selectNewLogo = () => {
  logoInput.value.click();
};

const notAllowed = () => {
  console.log('Not allowed!');
};

const selectNewInvoiceLogo = () => {
  invoiceLogoInput.value.click();
};

const updateLogoPreview = () => {
  const photo = logoInput.value.files[0];
  if (!photo) return;

  const reader = new FileReader();
  reader.onload = e => {
    logoPreview.value = e.target.result;
  };
  reader.readAsDataURL(photo);
};

const updateInvoiceLogoPreview = () => {
  const photo = invoiceLogoInput.value.files[0];
  if (!photo) return;

  const reader = new FileReader();
  reader.onload = e => {
    invoiceLogoPreview.value = e.target.result;
  };
  reader.readAsDataURL(photo);
};

// const deleteLogo = () => {
//   router.delete(route('current-user-photo.destroy'), {
//     preserveScroll: true,
//     onSuccess: () => {
//       logoPreview.value = null;
//       clearLogoFileInput();
//     },
//   });
// };

// const clearLogoFileInput = () => {
//   if (logoInput.value?.value) {
//     logoInput.value.value = null;
//   }
// };
</script>

<template>
  <AppLayout :title="t('Settings')">
    <div class="max-w-7xl mx-auto py-10 sm:px-6 lg:px-8">
      <FormSection @submitted="submit" autocomplete="off">
        <template #title>{{ t('Settings') }}</template>
        <template #description>{{ t('Please fill the form below to update settings.') }}</template>

        <template #form>
          <div class="col-span-6 sm:col-span-3">
            <!-- Logo File Input -->
            <input ref="logoInput" type="file" class="hidden" accept=".png,.jpg,.jpeg,.svg" @change="updateLogoPreview" />
            <JetLabel for="logo" :value="t('Login Logo')" />

            <!-- Current Logo -->
            <div v-show="!logoPreview && form.login_logo" class="my-2 rounded-md bg-white p-2">
              <img :src="form.login_logo" :alt="form.name" class="block rounded w-80 h-20 mx-auto bg-contain" />
            </div>

            <!-- New Logo Preview -->
            <div v-show="logoPreview" class="my-2 rounded-md bg-white p-2">
              <span
                class="block rounded w-80 h-20 mx-auto bg-contain bg-no-repeat bg-center"
                :style="'background-image: url(\'' + logoPreview + '\');'"
              />
            </div>

            <JetSecondaryButton class="mt-2 mr-2" type="button" @click.prevent="selectNewLogo">
              {{ t('Select Login Logo') }}
            </JetSecondaryButton>

            <!-- <JetSecondaryButton v-if="form.logo" type="button" class="mt-2" @click.prevent="deleteLogo">
              {{ t('Remove Logo') }}
            </JetSecondaryButton> -->
            <JetInputError :message="form.errors.login_logo" class="mt-2" />
          </div>

          <div class="col-span-6 sm:col-span-3">
            <!-- Invoice Logo File Input -->
            <input ref="invoiceLogoInput" type="file" class="hidden" accept=".png,.jpg,.jpeg,.svg" @change="updateInvoiceLogoPreview" />
            <JetLabel for="invoice_logo" :value="t('Invoice Logo')" />

            <!-- Current Invoice Logo -->
            <div v-show="!invoiceLogoPreview && form.invoice_logo" class="my-2 rounded-md bg-white p-2">
              <img :src="form.invoice_logo" :alt="form.name" class="block rounded w-80 h-20 mx-auto bg-contain" />
            </div>

            <!-- New Invoice Logo Preview -->
            <div v-show="invoiceLogoPreview" class="my-2 rounded-md bg-white p-2">
              <span
                class="block rounded w-80 h-20 mx-auto bg-contain bg-no-repeat bg-center"
                :style="'background-image: url(\'' + invoiceLogoPreview + '\');'"
              />
            </div>

            <JetSecondaryButton class="mt-2 mr-2" type="button" @click.prevent="selectNewInvoiceLogo">
              {{ t('Select Invoice Logo') }}
            </JetSecondaryButton>

            <!-- <JetSecondaryButton v-if="form.invoice_logo" type="button" class="mt-2" @click.prevent="deleteLogo">
              {{ t('Remove Logo') }}
            </JetSecondaryButton> -->
            <JetInputError :message="form.errors.invoice_logo" class="mt-2" />
          </div>

          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.name" :error="form.errors.name" :label="t('Site Name')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              :json="true"
              id="language"
              :searchable="false"
              v-model="form.language"
              :label="t('Language')"
              :error="form.errors.language"
              :suggestions="props.languages"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              :json="true"
              id="reference"
              :searchable="false"
              v-model="form.reference"
              :label="t('Reference')"
              :error="form.errors.reference"
              :suggestions="[
                { value: 'ulid', label: 'ULID - Universally Unique Lexicographically Sortable Identifier' },
                { value: 'ai', label: 'Auto Increment (MYSQL only)' },
                { value: 'uniqid', label: 'Uniqid - PHP Generate a Unique ID' },
                { value: 'uuid', label: 'UUID - Universally Unique Identifier' },
              ]"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.currency_code" :error="form.errors.currency_code" :label="t('Currency Code')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.default_locale" :error="form.errors.default_locale" :label="t('Date & Number Locale')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              id="hour12"
              :json="true"
              :searchable="false"
              v-model="form.hour12"
              :label="t('Time Format')"
              :error="form.errors.hour12"
              :suggestions="[
                { value: '0', label: '24 Hours (23:30)' },
                { value: '1', label: '12 Hours (11:30 PM)' },
              ]"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              id="fraction"
              :searchable="false"
              v-model="form.fraction"
              :suggestions="[0, 1, 2]"
              :error="form.errors.fraction"
              :label="t('Decimal Fractions')"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              id="per_page"
              :searchable="false"
              v-model="form.per_page"
              :error="form.errors.per_page"
              :label="t('Table rows per page')"
              :suggestions="[10, 15, 25, 50, 100]"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              id="initial_rows"
              :searchable="false"
              v-model="form.initial_rows"
              :suggestions="[2, 5, 10, 20]"
              :error="form.errors.initial_rows"
              :label="t('Initial rows on order form')"
            />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              :json="true"
              id="invoice_status"
              :searchable="false"
              :label="t('Invoice Status')"
              v-model="form.invoice_status"
              :suggestions="[
                { value: 'badge', label: t('As Badge') },
                { value: 'text', label: t('As Text') },
              ]"
              :error="form.errors.invoice_status"
            />
          </div>
          <div class="col-span-6">
            <TextInput v-model="form.attachment_exts" :error="form.errors.attachment_exts" :label="t('Allowed attachments')" />
          </div>
          <!-- <div class="col-span-6 sm:col-span-3">
            <AutoComplete
              id="default_tax_rate"
              :searchable="false"
              v-model="form.default_tax_rate"
              :label="t('Default tax rate')"
              :error="form.errors.default_tax_rate"
              :suggestions="[
                { value: 2, label: 2 },
                { value: 5, label: 5 },
                { value: 10, label: 10 },
                { value: 20, label: 20 },
              ]"
            />
          </div> -->

          <!-- <div class="col-span-full"></div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf1" :error="form.errors.customer_cf1" :label="t('Label for customer field 1')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf2" :error="form.errors.customer_cf2" :label="t('Label for customer field 2')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf3" :error="form.errors.customer_cf3" :label="t('Label for customer field 3')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf4" :error="form.errors.customer_cf4" :label="t('Label for customer field 4')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf5" :error="form.errors.customer_cf5" :label="t('Label for customer field 5')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.customer_cf6" :error="form.errors.customer_cf6" :label="t('Label for customer field 6')" />
          </div>
          <div class="col-span-full"></div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf1" :error="form.errors.company_cf1" :label="t('Label for company field 1')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf2" :error="form.errors.company_cf2" :label="t('Label for company field 2')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf3" :error="form.errors.company_cf3" :label="t('Label for company field 3')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf4" :error="form.errors.company_cf4" :label="t('Label for company field 4')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf5" :error="form.errors.company_cf5" :label="t('Label for company field 5')" />
          </div>
          <div class="col-span-6 sm:col-span-3">
            <TextInput v-model="form.company_cf6" :error="form.errors.company_cf6" :label="t('Label for company field 6')" />
          </div> -->

          <div class="col-span-full">
            <CheckBox
              id="paypal-enabled"
              :label="t('Enable PayPal Payments')"
              v-model:checked="form.paypal.enabled"
              :error="form.errors.paypal?.enabled"
            />
            <div v-if="form.paypal.enabled" class="my-4 grid grid-cols-1 sm:grid-cols-6 gap-4">
              <div class="col-span-6">
                <TextInput v-model="form.paypal.client_id" :error="form.errors.paypal?.client_id" :label="t('PayPal Client Id')" />
              </div>
              <div class="col-span-6">
                <TextInput v-model="form.paypal.secret" :error="form.errors.paypal?.secret" :label="t('PayPal Secret')" />
              </div>
              <div class="col-span-2">
                <TextInput v-model="form.paypal.fixed" :error="form.errors.paypal?.fixed" :label="t('Fixed Fee Amount')" />
              </div>
              <div class="col-span-2">
                <TextInput
                  v-model="form.paypal.same_country"
                  :error="form.errors.paypal?.same_country"
                  :label="t('Same Country Percentage')"
                />
              </div>
              <div class="col-span-2">
                <TextInput
                  v-model="form.paypal.other_countries"
                  :error="form.errors.paypal?.other_countries"
                  :label="t('Other Countries Percentage')"
                />
              </div>
            </div>
          </div>

          <div class="col-span-full">
            <CheckBox
              id="stripe-enabled"
              :label="t('Enable Stripe Payments')"
              v-model:checked="form.stripe.enabled"
              :error="form.errors.stripe?.enabled"
            />
            <div v-if="form.stripe.enabled" class="my-4 grid grid-cols-1 sm:grid-cols-6 gap-4">
              <div class="col-span-6">
                <TextInput
                  v-model="form.stripe.publishable_key"
                  :error="form.errors.stripe?.publishable_key"
                  :label="t('Stripe Publishable Key')"
                />
              </div>
              <div class="col-span-6">
                <TextInput v-model="form.stripe.secret_key" :error="form.errors.stripe?.secret_key" :label="t('Stripe Secret Key')" />
              </div>
              <div class="col-span-2">
                <TextInput v-model="form.stripe.fixed" :error="form.errors.stripe?.fixed" :label="t('Fixed Fee Amount')" />
              </div>
              <div class="col-span-2">
                <TextInput
                  v-model="form.stripe.same_country"
                  :error="form.errors.stripe?.same_country"
                  :label="t('Same Country Percentage')"
                />
              </div>
              <div class="col-span-2">
                <TextInput
                  v-model="form.stripe.other_countries"
                  :error="form.errors.stripe?.other_countries"
                  :label="t('Other Countries Percentage')"
                />
              </div>
            </div>
          </div>

          <div class="col-span-full flex flex-col gap-4">
            <!-- <CheckBox
                id="product_discount"
                :label="t('Enable product discount')"
                :error="form.errors.product_discount"
                v-model:checked="form.product_discount"
                />
                <CheckBox
                id="create_user"
                :error="form.errors.create_user"
                v-model:checked="form.create_user"
                :label="t('Auto create user for new customer')"
                /> -->
            <CheckBox
              id="impersonation"
              :error="form.errors.impersonation"
              v-model:checked="form.impersonation"
              :label="t('Enable impersonation of customer user')"
            />
          </div>
        </template>

        <template #actions v-if="$can('create-settings')">
          <ActionMessage :on="form.recentlySuccessful" class="mr-3"> {{ t('Saved.') }} </ActionMessage>
          <Button :type="$can('create-settings') ? 'submit' : 'button'" :loading="form.processing">
            {{ t('Save') }}
          </Button>
        </template>
      </FormSection>

      <div v-if="form && form?.default_locale" class="mt-8">
        <FormSection>
          <template #title>{{ t('Preview') }}</template>
          <template #description>{{ t('Number and Date Format') }}</template>

          <template #form>
            <div class="col-span-full -m-6 rounded-md overflow-hidden">
              <dl>
                <div
                  class="odd:bg-white dark:odd:bg-gray-900 even:bg-gray-50 dark:even:bg-black/20 px-4 py-5 sm:grid sm:grid-cols-3 sm:gap-4 sm:px-6"
                >
                  <dt class="font-medium text-gray-500 dark:text-gray-400">{{ t('Currency') }}</dt>
                  <dd class="mt-1 sm:mt-0 sm:col-span-2">
                    {{
                      $currency(20000000.5, form.default_locale, {
                        minimumFractionDigits: form.fraction,
                      })
                    }}
                  </dd>
                </div>
                <div
                  class="odd:bg-white dark:odd:bg-gray-900 even:bg-gray-50 dark:even:bg-black/20 px-4 py-5 sm:grid sm:grid-cols-3 sm:gap-4 sm:px-6"
                >
                  <dt class="font-medium text-gray-500 dark:text-gray-400">{{ t('Number') }}</dt>
                  <dd class="mt-1 sm:mt-0 sm:col-span-2">
                    {{
                      $number(20000000.5, form.default_locale, {
                        minimumFractionDigits: form.fraction,
                      })
                    }}
                  </dd>
                </div>
                <div
                  class="odd:bg-white dark:odd:bg-gray-900 even:bg-gray-50 dark:even:bg-black/20 px-4 py-5 sm:grid sm:grid-cols-3 sm:gap-4 sm:px-6"
                >
                  <dt class="font-medium text-gray-500 dark:text-gray-400">{{ t('Date') }}</dt>
                  <dd class="mt-1 sm:mt-0 sm:col-span-2">
                    {{ $date(new Date(), form.default_locale) }}
                  </dd>
                </div>
                <div
                  class="odd:bg-white dark:odd:bg-gray-900 even:bg-gray-50 dark:even:bg-black/20 px-4 py-5 sm:grid sm:grid-cols-3 sm:gap-4 sm:px-6"
                >
                  <dt class="font-medium text-gray-500 dark:text-gray-400">{{ t('Date Time') }}</dt>
                  <dd class="mt-1 sm:mt-0 sm:col-span-2">
                    {{ $datetime(new Date(), form.default_locale) }}
                  </dd>
                </div>
              </dl>
            </div>
          </template>
        </FormSection>
      </div>
    </div>
  </AppLayout>
</template>
